% Monetary Regime-Switches and Central Bank Preferences 
% Debortoli and Nunes (JMCB)
%
% Equations to solve the regime-switching model using a fixed point problem in the policy coefficients of the two regimes
% Output:
% - z: vector of residuals to be set to zero by a Newton Algorithm
%
% Input:
% - CoeffGuess: vector of candidate coefficients for the policy functions
% - pol_parameters_A, pol_parameters_B: values of policymakers' preferences


function z=Pol_FixPoint(CoefGuess, pol_parameters_A, pol_parameters_B)
global betta sigma rho kappa rho_u prob_COM

ncoeff = length(CoefGuess);
Coeff_A = CoefGuess(1:ncoeff/2,:);
Coeff_B = CoefGuess(ncoeff/2+1:end,:);

% Regime A given policy of B
[G1_A, C_A, impact_A] = solve_model(pol_parameters_A,Coeff_B);

% Regime B given policy of A
[G1_B, C_B, impact_B] = solve_model(pol_parameters_B,Coeff_A);

if ncoeff==8
    z = [impact_A(:) - Coeff_A(:); ...
         impact_B(:) - Coeff_B(:)];
else
    z = [[impact_A(:); G1_A(:)] - Coeff_A(:); ...
        [impact_B(:); G1_B(:)] - Coeff_B(:)];
end