% Monetary Regime-Switches and Central Bank Preferences 
% Debortoli and Nunes (JMCB)
%
% File containing the model equations:
%
% Output: Euler residuals
%
% Inputs: 
% x:                values of the variables
% pol_parameters:   values of poicymaker's preferences
% psi_B:            policy functions of alternative regime


function resid = equs(x, pol_parameters, psi_B)
global betta sigma rho kappa rho_u prob_COM

w        = pol_parameters(1);

% VARIABLES
y   = x(1); % output gap
pi  = x(2); % inflation
i   = x(3); % nominal interest rate
u   = x(4); % cost-push shock

y_lag   = x(11); % output gap
pi_lag  = x(12); % inflation
i_lag   = x(13); % nominal interest rate 
u_lag   = x(14); % cost-push shock

y_B    = psi_B(1)*u;
pi_B   = psi_B(2)*u;

% EXOGENOUS SHOCKS
epsu    = x(21);    %innovation cost push shock

% EXPECATION ERRORS
etaPC  = x(31); %for NKPC
etaDIS = x(32); %for Dynamic IS (DIS)

NKPC = -pi_lag + betta*prob_COM*pi + betta*(1-prob_COM)*pi_B + kappa*y_lag + u_lag + etaPC;  % NKPC
DIS  = -y_lag - (1/sigma)*(i_lag-(prob_COM*pi + (1-prob_COM)*pi_B)-rho) + prob_COM*y + (1-prob_COM)*y_B + etaDIS; %DIS
FOC  = - pi + w/kappa*(y_lag*(prob_COM>0)-y);

% EQUATIONS OF THE MODEL
resid = zeros(4,1);
resid(1) = -u + rho_u*u_lag + epsu; % process for the cost-push shock 
resid(2) = NKPC;
resid(3) = DIS;
resid(4) = FOC;
