% Monetary Regime-Switches and Central Bank Preferences 
% Debortoli and Nunes (JMCB)
%
% File to solve the model using GENSYS (by C. Sims)
% 
% Output: Matrices (G1, C, impact) of the state space form: x(t) = C+ G1*x(t-1) + impact
%
% Inputs: 
% x:                values of the variables
% pol_parameters:   values of poicymaker's preferences
% psi_B:            policy functions of alternative regime

% It calls the function
% - equs.m : contains the model equations

function [G1,C,impact]=solve_model(pol_parameters,psiB)
global betta sigma rho kappa rho_u prob_COM

% Check model equations in a zero inflation steady state:
y   = 0;   % output gap
pi  = 0;   % inflation
i   = rho; % nominal interest rate

stst = [y, pi, i, 0]';

ix = [1:4]';
ieps = [21]';
ieta = [31:32]';
ixlag = ix+10;

stst2 = zeros(34,1);
stst2([ixlag ix]) = repmat(stst,2,1);

check = max(abs(equs(stst2,pol_parameters,psiB)));
disp('Maximum residual at stst:');

disp(check);
if check>1e-5
    error('Something wrong in the equations');   % ALWAYS CHECK THAT THIS IS VERY SMALL!!;
end

% Computing Jacobian (precision important, computing time doesn't matter)
jac = jacob(@equs,stst2,1e-5,pol_parameters,psiB);
g0 = -jac(:,ix);
g1 = jac(:,ixlag);
c   = equs(zeros(length(stst2),1),pol_parameters,psiB);
Psi = jac(:,ieps);
Pi  = jac(:,ieta);

% Criterion for what is a stable solution:
% here our model is stationary, so choose
div = 1;
[eu,eigvals] = checkeu(g0,g1,Psi,Pi,div);
'existence and uniquenes?'
disp(eu');
'generalized eigenvalues:'
fprintf(1,'%g  ',eigvals);
fprintf(1,'\n');
[G1,C,impact,fmat,fwt,ywt,gev,eu]=gensys(g0,g1,c,Psi,Pi,div); %see eq. 44 in Sims' paper for the meaning.